event

package
v0.5.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 22, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Overview

Package event provides handlers for common DOM events.

See domi.On to define custom event handlers.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Change added in v0.5.1

func Change[Msg any](f func(value string) Msg) domi.Attr

Change responds to "change" events on text fields, text areas, and select elements. It calls f with the new value and delivers the resulting message.

func Check

func Check[Msg any](f func(checked bool) Msg) domi.Attr

Check responds to "change" events on checkboxes and radio buttons. It calls f with the new value and delivers the resulting message.

func Click

func Click[Msg any](msg Msg) domi.Attr

Click delivers msg when the element is clicked.

func Input

func Input[Msg any](f func(value string) Msg) domi.Attr

Input responds to "input" events on text fields and text areas. It calls f with the new value and delivers the resulting message.

func Submit

func Submit[Msg any](msg Msg) domi.Attr

Submit delivers msg when the element's form is submitted.

Types

This section is empty.

Jump to