Documentation
¶
Overview ¶
Package event provides handlers for common DOM events.
See domi.On to define custom event handlers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Change ¶ added in v0.5.1
Change responds to "change" events on text fields, text areas, and select elements. It calls f with the new value and delivers the resulting message.
func Check ¶
Check responds to "change" events on checkboxes and radio buttons. It calls f with the new value and delivers the resulting message.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.